'use client'
import { motion } from "motion/react";
import { Navbar } from "@/components/navbar";
import { Button } from "@/components/ui/button";
import { ArrowRight, CheckCircle, MessageCircle } from "lucide-react";

export default function Home() {
  return (
    <div className="min-h-screen bg-gray-900 text-white flex flex-col items-center">
      <Navbar />

      {/* Hero Section */}
      <motion.div
        initial={{ opacity: 0, y: -20 }}
        animate={{ opacity: 1, y: 0 }}
        transition={{ duration: 0.8 }}
        className="text-center max-w-2xl p-8 mt-16"
      >
        <h1 className="text-5xl font-bold mb-6 leading-tight">
          Organize Your Life, One Task at a Time
        </h1>
        <p className="text-lg mb-6">
          Boost your productivity with Todoist. Plan, manage, and track your tasks seamlessly.
        </p>
        <motion.div
          className="flex justify-center"
          whileHover={{ scale: 1.1 }}
          whileTap={{ scale: 0.9 }}
        >
          <Button className="bg-white text-gray-900 font-semibold px-6 py-3 rounded-full flex items-center gap-2 shadow-lg">
            Get Started <ArrowRight size={18} />
          </Button>
        </motion.div>
      </motion.div>

      {/* Features Section */}
      <div className="mt-16 max-w-4xl text-center">
        <h2 className="text-3xl font-semibold mb-6">Why Choose Todoist?</h2>
        <motion.div
          className="grid grid-cols-1 md:grid-cols-3 gap-6"
          initial={{ opacity: 0, y: 30 }}
          animate={{ opacity: 1, y: 0 }}
          transition={{ duration: 0.8, staggerChildren: 0.3 }}
        >
          {["Easy to Use", "Stay Organized", "Cloud Based"].map((feature, index) => (
            <motion.div
              key={index}
              className="p-6 bg-gray-800 text-white rounded-lg shadow-md"
              initial={{ opacity: 0, y: 20 }}
              animate={{ opacity: 1, y: 0 }}
              transition={{ duration: 0.5, delay: index * 0.2 }}
            >
              <CheckCircle size={40} className="mx-auto mb-4" />
              <h3 className="font-semibold text-xl">{feature}</h3>
              <p className="text-gray-400">
                {feature === "Easy to Use" && "Simple and intuitive interface to get started quickly."}
                {feature === "Stay Organized" && "Keep track of all your tasks effortlessly."}
                {feature === "Cloud Based" && "Access your tasks from any device, anywhere in the world."}
              </p>
            </motion.div>
          ))}
        </motion.div>
      </div>

      {/* Testimonials Section */}
      <div className="mt-16 max-w-4xl text-center">
        <h2 className="text-3xl font-semibold mb-6">What Our Users Say</h2>
        <motion.div 
          className="p-6 bg-gray-800 text-white rounded-lg shadow-md max-w-2xl mx-auto"
          initial={{ opacity: 0, y: 20 }}
          animate={{ opacity: 1, y: 0 }}
          transition={{ duration: 0.8 }}
        >
          <motion.div
            whileHover={{ scale: 1.05 }}
            whileTap={{ scale: 0.95 }}
          >
            <MessageCircle size={40} className="mx-auto mb-4" />
            <p className="text-gray-400 italic">&quot;Todoist helps me keep track of all my... let&apos;s call them &apos;financial transactions.&apos; No more misplaced &apos;funds!&apos;&quot;</p>
            <p className="font-semibold mt-4">- Mulyono</p>
          </motion.div>
        </motion.div>
      </div>

      {/* Footer */}
      <footer className="mt-16 p-6 bg-gray-800 w-full text-center">
        <p>&copy; 2025 Todoist. All Rights Reserved.</p>
      </footer>
    </div>
  );
}
